@@ -1,11 +1,13 @@
 package WordList::EN::SGB;
 
 our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
+our %STATS = ("shortest_word_len",5,"longest_word_len",5,"avg_word_len",5,"num_words_contains_whitespace",0,"num_words_contains_unicode",0,"num_words",5757,"num_words_contains_nonword_chars",0); # STATS
+
 1;
 # ABSTRACT: The Stanford GraphBase word list
 
@@ -22,7 +24,7 @@ WordList::EN::SGB - The Stanford GraphBase word list
 
 =head1 VERSION
 
-This document describes version 0.02 of WordList::EN::SGB (from Perl distribution WordList-EN-SGB), released on 2016-01-13.
+This document describes version 0.03 of WordList::EN::SGB (from Perl distribution WordList-EN-SGB), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -43,6 +45,22 @@ This document describes version 0.02 of WordList::EN::SGB (from Perl distributio
  # Get all the words
  my @all_words = $wl->all_words;
 
+=head1 STATISTICS
+
+ +----------------------------------+-------+
+ | key                              | value |
+ +----------------------------------+-------+
+ | avg_word_len                     | 5     |
+ | longest_word_len                 | 5     |
+ | num_words                        | 5757  |
+ | num_words_contains_nonword_chars | 0     |
+ | num_words_contains_unicode       | 0     |
+ | num_words_contains_whitespace    | 0     |
+ | shortest_word_len                | 5     |
+ +----------------------------------+-------+
+
+The statistics is available in the C<%STATS> package variable.
+
 =head1 SEE ALSO
 
 Converted from L<Games::Word::Wordlist::SGB> 2010091501.
